@@ -68,7 +68,7 @@ def get_defense_category(method):
 
 def get_node_ns(graph, k=3):
     """
-    Get k nodes to defend based on the Netshield algorithm :cite:`tong2010vulnerability,chen2015node`.
+    Get k nodes to defend based on the Netshield algorithm :cite:`tong2010vulnerability`.
 
     :param graph: an undirected NetworkX graph
     :param k: number of nodes to defend
@@ -425,7 +425,9 @@ categories = {
     'pr_node': 'node',
     'eig_node': 'node',
     'id_node': 'node',
+    'rd_node': 'node',
     'ib_node': 'node',
+    'rb_node': 'node',
     'rnd_node': 'node',
 
     'add_edge_pr': 'edge',
@@ -446,7 +448,9 @@ methods = {
     'pr_node': get_node_pr,
     'eig_node': get_node_eig,
     'id_node': get_node_id,
+    'rd_node': get_node_rd,
     'ib_node': get_node_ib,
+    'rb_node': get_node_rb,
     'rnd_node': get_node_rnd,
 
     'add_edge_pr': add_edge_pr,
@@ -602,7 +606,7 @@ class Defense(Simulation):
 
 
 def main():
-    graph = graph_loader(graph_type='water', seed=1)
+    graph = graph_loader(graph_type='ky2', seed=1)
 
     params = {
         'runs': 1,
